import L from "leaflet";
import LeafletWmsOptions from "../model/leaflet/LeafletWmsOptions";
import LeafletWmtsOptions from "../model/leaflet/LeafletWmtsOptions";
interface Bounds {
    minLat?: number;
    minLon?: number;
    maxLat?: number;
    maxLon?: number;
}
declare class OgcXmlParser {
    static readonly WMTS = "WMTS";
    static readonly WMS = "WMS";
    static readonly WFS = "WFS";
    static readonly SupportedCRS = "ows:SupportedCRS";
    static readonly SupportedCRS_Flag = "urn:ogc:def:crs:EPSG::";
    static readonly Default_Epsg_3857 = "urn:ogc:def:crs:EPSG::3857";
    static readonly TileMatrixSet = "TileMatrixSet";
    static readonly TileMatrix = "TileMatrix";
    static readonly Identifier = "ows:Identifier";
    static readonly Layer = "Layer";
    static readonly Title = "ows:Title";
    static readonly TileMatrixSetLink = "TileMatrixSetLink";
    static readonly EX_GeographicBoundingBox = "EX_GeographicBoundingBox";
    static readonly WGS84BoundingBox = "ows:WGS84BoundingBox";
    static getWmtsCapabilitiesUrl(url: string): string;
    static getWmsCapabilitiesUrl(url: string, version?: string): string;
    static getWmsLayers(xmlData: string): string;
    static getWmtsLayer(xmlData: string): string;
    static getWmtsLayerTitle(xmlData: string): string;
    static getOgcLayerCrs(xmlData: string): string;
    static getOgcLayerMinMaxZoom(xmlData: string): {
        minZoom: number;
        maxZoom: number;
    };
    static getWmtsTileMatrix(xmlData: string): string;
    static getWmtsOptions(xmlData: string): LeafletWmtsOptions;
    static getWmsOptions(xmlData: string, options?: {
        format: string;
        transparent: boolean;
    }): LeafletWmsOptions;
    static getWmsBounds(xmlData: string): Bounds;
    static wrapperBounds(bounds: Bounds): Bounds;
    static getFitBounds(xmlData: string, service?: string): L.LatLngBounds;
    static getWMTSBounds(xmlData: string): Bounds;
    static getOgcCenter(xmlData: string, service?: string): number[];
    static createCoordinate(lat: number, lon: number): L.LatLng;
    static getNodeValue(node: any, tagName: string): any;
}
export default OgcXmlParser;
